@@ -18,12 +18,13 @@
 #
 # Copyright 2000-2004 Free Software Foundation
 #
-# $Id: CHGroupHeader.py 6706 2004-11-22 12:26:58Z btami $
+# $Id: CHGroupHeader.py 6763 2004-11-30 23:36:21Z jcater $
 #
 # DESCRIPTION:
-# Class that contains xml objects for GNUe Reports'
-# "Char" markup.
-#
+"""
+Class that contains xml objects for GNUe Reports'
+"Char" markup.
+"""
 # NOTES:
 #
 
@@ -31,16 +32,8 @@ __all__ = ['CHGroupHeader']
 
 from CHObject import CHObject, CHBand
 
-class CHGroupHeader(CHObject, CHBand): 
+class CHGroupHeader(CHObject, CHBand):
   def __init__(self, parent=None, type='CHGroupHeader'):
     CHObject.__init__(self, parent, type=type)
     CHBand.__init__(self)
 
-  def process(self, writer):
-    for child in self._children:
-      child.process(writer, self)
-
-    if self.height > self.y+1:
-      writer.newLine(self.height-self.y-1)
-
-    self.resetBand()
