@@ -18,12 +18,13 @@
 #
 # Copyright 2000-2004 Free Software Foundation
 #
-# $Id: CHLabel.py 6706 2004-11-22 12:26:58Z btami $
+# $Id: CHLabel.py 6763 2004-11-30 23:36:21Z jcater $
 #
 # DESCRIPTION:
-# Class that contains xml objects for GNUe Reports'
-# "Char" markup.
-#
+"""
+Class that contains xml objects for GNUe Reports'
+"Char" markup.
+"""
 # NOTES:
 #
 
@@ -31,7 +32,7 @@ __all__ = ['CHLabel']
 
 from CHObject import CHObject
 
-class CHLabel(CHObject): 
+class CHLabel(CHObject):
   def __init__(self, parent=None, type='CHLabel'):
     CHObject.__init__(self, parent, type=type)
 
