@@ -18,12 +18,13 @@
 #
 # Copyright 2000-2004 Free Software Foundation
 #
-# $Id: CHObject.py 6706 2004-11-22 12:26:58Z btami $
+# $Id: CHObject.py 6763 2004-11-30 23:36:21Z jcater $
 #
 # DESCRIPTION:
-# Class that contains xml objects for GNUe Reports'
-# "Char" markup.
-#
+"""
+Class that contains xml objects for GNUe Reports'
+"Char" markup.
+"""
 # NOTES:
 #
 
@@ -32,16 +33,28 @@ __all__ = ['CHObject', 'CHBand']
 from gnue.common.definitions.GObjects import GObj
 
 
-class CHObject(GObj): 
+class CHObject(GObj):
   def __init__(self, parent=None, type='CHObject'):
     GObj.__init__(self, parent, type=type)
 
 
-class CHBand: 
+class CHBand:
+  splittable = False # This band is not splittable across pages
   def __init__(self):
-    self.resetBand()
+    self._inits = [self.resetBand]
 
   def resetBand(self):
     self.x = 0
     self.y = -1
+    self.buffer = []
+    # Make sure buffer is big enough
+    for i in xrange(self.height): 
+      self.buffer.append([])
 
+
+  def process(self, writer):
+    for child in self._children:
+      child.process(writer, self)
+
+    writer.renderBand(self)
+    self.resetBand()
