@@ -18,12 +18,13 @@
 #
 # Copyright 2000-2004 Free Software Foundation
 #
-# $Id: CHPageFooter.py 6706 2004-11-22 12:26:58Z btami $
+# $Id: CHPageFooter.py 6763 2004-11-30 23:36:21Z jcater $
 #
 # DESCRIPTION:
-# Class that contains xml objects for GNUe Reports'
-# "Char" markup.
-#
+"""
+Class that contains xml objects for GNUe Reports'
+"Char" markup.
+"""
 # NOTES:
 #
 
@@ -32,7 +33,7 @@ __all__ = ['CHPageFooter']
 from CHObject import CHObject, CHBand
 
 
-class CHPageFooter(CHObject, CHBand): 
+class CHPageFooter(CHObject, CHBand):
   def __init__(self, parent=None, type='CHPageFooter'):
     CHObject.__init__(self, parent, type=type)
     CHBand.__init__(self)
@@ -40,12 +41,6 @@ class CHPageFooter(CHObject, CHBand):
   def process(self, writer):
     writer.pageFooterDone = True
     if writer.currLine < writer.reportHeight - self.height:
-      writer.newLine(writer.reportHeight - self.height - writer.currLine)
+      writer.printLines([""] * (writer.reportHeight - self.height - writer.currLine), self._type)
 
-    for child in self._children:
-      child.process(writer, self)
-
-    if self.height > self.y+1:
-      writer.newLine(self.height-self.y-1)
-
-    self.resetBand()
+    CHBand.process(self, writer)
