@@ -18,12 +18,13 @@
 #
 # Copyright 2000-2004 Free Software Foundation
 #
-# $Id: CHPageHeader.py 6706 2004-11-22 12:26:58Z btami $
+# $Id: CHPageHeader.py 6763 2004-11-30 23:36:21Z jcater $
 #
 # DESCRIPTION:
-# Class that contains xml objects for GNUe Reports'
-# "Char" markup.
-#
+"""
+Class that contains xml objects for GNUe Reports'
+"Char" markup.
+"""
 # NOTES:
 #
 
@@ -32,17 +33,12 @@ __all__ = ['CHPageHeader']
 from CHObject import CHObject, CHBand
 
 
-class CHPageHeader(CHObject, CHBand): 
+class CHPageHeader(CHObject, CHBand):
   def __init__(self, parent=None, type='CHPageHeader'):
     CHObject.__init__(self, parent, type=type)
     CHBand.__init__(self)
 
   def process(self, writer):
     writer.pageHeaderDone = True
-    for child in self._children:
-      child.process(writer, self)
-
-    if self.height > self.y+1:
-      writer.newLine(self.height-self.y-1)
-
-    self.resetBand()
+    CHBand.process(self, writer)
+    
\ No newline at end of file
