@@ -18,11 +18,13 @@
 #
 # Copyright 2000-2004 Free Software Foundation
 #
-# $Id: CHTitlePage.py 6706 2004-11-22 12:26:58Z btami $
+# $Id: CHTitlePage.py 6763 2004-11-30 23:36:21Z jcater $
 #
 # DESCRIPTION:
-# Class that contains xml objects for GNUe Reports'
-# "Char" markup.
+"""
+Class that contains xml objects for GNUe Reports'
+"Char" markup.
+"""
 #
 # NOTES:
 #
@@ -31,17 +33,18 @@ __all__ = ['CHTitlePage']
 
 from CHObject import CHObject, CHBand
 
-class CHTitlePage(CHObject, CHBand): 
+class CHTitlePage(CHObject, CHBand):
   def __init__(self, parent=None, type='CHTitlePage'):
     CHObject.__init__(self, parent, type=type)
+    self.height = parent.height
     CHBand.__init__(self)
-
+    
 
   def process(self, writer):
+    writer.newPage()
     writer.pageHeaderDone = True
     writer.pageFooterDone = True
     
-    for child in self._children:
-      child.process(writer, self)
-
+    CHBand.process(self, writer)
     writer.newPage()
+
