@@ -16,7 +16,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# Copyright 2000-2004 Free Software Foundation
+# Copyright 2000-2005 Free Software Foundation
 #
 # FILE:
 # GRDataMapper.py
@@ -54,6 +54,8 @@ class GRDataMapperSection:
     self.sections = []
     self.fields = {}
     self.summaries = {}
+    self.formulas = {}
+    self.formulaObjects = {}
     self._fieldsOld = {}
     self.toplevel = 0   # Is this the first section to use a datasource
     self.initial = 1    # Are we in an initial run in which we have no history?
@@ -95,25 +97,32 @@ class GRDataMapperSection:
   def addField(self, name):
     self.fields[name] = ""
 
-
   #
   #  Add a summary
   #
-  def addSummary(self, function, field):
+  def addSummary(self, function, key):
     try:
-      self.summaries[field][function] = None
+      self.summaries[key][function] = None
     except KeyError:
-      self.summaries[field] = {function:None}
+      self.summaries[key] = {function:None}
 
     # If this function relies on other
     # functions, add those as well (e.g.,
     # average depends on sum and count)
     try:
       for func in _summMultiMapping[function]:
-        self.addSummary(self, func, field)
+        self.addSummary(self, func, key)
     except KeyError:
       pass
 
+  #
+  #  Add a formula
+  #
+  def addFormula(self, name, object):
+    self.formulas[name] = None
+    self.formulaObjects[name] = object
+
+
 
   #
   #  Get a field's current value
@@ -131,6 +140,16 @@ class GRDataMapperSection:
     else:
       return "%s" % val
 
+  #
+  #  Get a formula's current value
+  #
+  def getFormula(self, name, format):
+    val = self.formulas[name]
+    if val is None:
+      return ""
+    else:
+      return GDataFormatter.applyFormatting("%s" % val, format)
+
   #
   #  Add a section
   #
@@ -142,9 +161,9 @@ class GRDataMapperSection:
   # Zero out the summary data
   #
   def clearSummaries(self):
-    for field in self.summaries.keys():
-      for function in self.summaries[field].keys():
-        self.summaries[field][function] = None
+    for key in self.summaries.keys():
+      for function in self.summaries[key].keys():
+        self.summaries[key][function] = None
     self._clearOnNextSet = 0
 
 
@@ -167,31 +186,9 @@ class GRDataMapperSection:
     return changed
 
 
-  #
-  # Initiate the calculation of summaries
-  #
-  # TODO: I **SERIOUSLY** don't think this is being used any longer
-  def _handleSummary(self):
-    if self._clearOnNextSet:
-      self.clearSummaries()
-    # Now, calc all summaries
-    for field in self.summaries.keys():
-      for function in _summFunctions:
-        if self.summaries[field].has_key(function):
-          try:
-            self._summMap[function](field, self.fields[field])
-          except KeyError:
-            pass
-
-
-  #  Used in GRSources.__connectMasterDetail to link detail datasource to
-  #  master source.  Called by GDataObjects.ResultSet when master changed
-  #  This will actually be over-written by GRDataMapper but at the time
-  #  the master-detail must be linked, the GRDataMapper will not have been
-  #  created yet.  [Yes, it's fugly]
-  def _masterChanged(self, masterResultSet, detailResultSet):
-    GDebug.printMesg (5, 'GRDataMapper._masterChanged on %s' % self.name)
-    self._resultsets.insert(0,detailResultSet)
+  def _dsResultSetActivated (self, event):
+    GDebug.printMesg (5, 'GRDataMapper._dsResultSetActivated on %s' % self.name)
+    self._resultsets.insert (0, event.resultSet)
 
 
   ##
@@ -199,45 +196,45 @@ class GRDataMapperSection:
   ##
 
   # Summary function: "count"
-  def _summ_count(self, field, value):
+  def _summ_count(self, key, value):
     if value is not None:
       try:
-        self.summaries[field]['count'] += 1
+        self.summaries[key]['count'] += 1
       except TypeError:
-        self.summaries[field]['count'] = 1
+        self.summaries[key]['count'] = 1
 
   # Summary function: "sum"
-  def _summ_sum(self, field, value):
+  def _summ_sum(self, key, value):
     if value is not None:
       if type(value) in _numericTypes:
         try:
-          self.summaries[field]['sum'] += FixedPoint(value)
+          self.summaries[key]['sum'] += FixedPoint(value)
         except TypeError:
-          self.summaries[field]['sum'] = FixedPoint(value)
+          self.summaries[key]['sum'] = FixedPoint(value)
       else:
-        raise "Attempting to 'sum' a non-numeric field %s" % (field)
+        raise "Attempting to 'sum' a non-numeric %s" % (key)
 
   # Summary function: "average"
-  def _summ_avg(self, field, value):
+  def _summ_avg(self, key, value):
     if type(value) in _numericTypes:
-      self.summaries[field]['average'] = \
-          self.summaries[field]['sum'] / self.summaries[field]['count']
+      self.summaries[key]['average'] = \
+          self.summaries[key]['sum'] / self.summaries[key]['count']
     else:
-      raise "Attempting to 'average' a non-numeric field %s" % (field)
+      raise "Attempting to 'average' a non-numeric %s" % (key)
 
   # Summary function: "min"
-  def _summ_min(self, field, value):
+  def _summ_min(self, key, value):
     if value is not None:
-      existing = self.summaries[field]['min']
+      existing = self.summaries[key]['min']
       if existing is None or value < existing:
-        self.summaries[field]['min'] = value
+        self.summaries[key]['min'] = value
 
   # Summary function: "max"
-  def _summ_max(self, field, value):
+  def _summ_max(self, key, value):
     if value is not None:
-      existing = self.summaries[field]['min']
+      existing = self.summaries[key]['min']
       if existing is None or value > existing:
-        self.summaries[field]['min'] = value
+        self.summaries[key]['min'] = value
 
 
 
@@ -254,8 +251,6 @@ class GRDataMapper(GRDataMapperSection):
     self.sourceMap = {}
 
   def addSection(self, section, source, parentSection):
-    if source == None:
-      return
     if self.sectionMap.has_key (section):
       raise GRExceptions.SectionHasDuplicateName, \
          'Section "%s" is defined multiple times' % section
@@ -265,7 +260,7 @@ class GRDataMapper(GRDataMapperSection):
     else:
       parentMapper = self.sectionMap[parentSection]
 
-    if self.sourceMap.has_key(source) and \
+    if self.sourceMap.has_key(source) and source != None and\
        not self.sourceMap[source][0].isAncestorOf(parentMapper):
       raise GRExceptions.SourceMappedToSiblingSections, \
          "Section '%s' attempts to use source '%s', but does not descend from '%s'" % \
@@ -279,8 +274,10 @@ class GRDataMapper(GRDataMapperSection):
       GDebug.printMesg(5,"Setting section %s as source controller" % self.name)
       self.sourceMap[source] = [mapper]
       mapper.toplevel = 1
-      mapper.datasource = self.sources.getDataSource(source)
-      mapper.datasource.masterResultSetChanged = mapper._masterChanged
+      if source != None:
+        mapper.datasource = self.sources.getDataSource(source)
+        mapper.datasource.registerEventListeners ({
+          'dsResultSetActivated': mapper._dsResultSetActivated})
     else:
       self.sourceMap[source][-1].grouping = 1
       self.sourceMap[source].append(mapper)
@@ -292,12 +289,14 @@ class GRDataMapper(GRDataMapperSection):
     self.sources.getDataSource(self.sectionMap[section].source) \
           .referenceField(field)
 
+  def addSummaryToSection(self, function, section, field, formula):
+    self.sectionMap[section].addSummary(function, (field, formula))
+    if field != 'none':
+      self.sources.getDataSource(self.sectionMap[section].source) \
+            .referenceField(field)
 
-  def addSummaryToSection(self, function, section, field):
-
-    self.sectionMap[section].addSummary(function, field)
-    self.sources.getDataSource(self.sectionMap[section].source) \
-          .referenceField(field)
+  def addFormulaToSection(self, section, name, object):
+    self.sectionMap[section].addFormula(name, object)
 
 
   #
@@ -318,8 +317,8 @@ class GRDataMapper(GRDataMapperSection):
     # as child sources were queries by the master
     if controlSection.parent == None or controlSection.parent.source == "":
       GDebug.printMesg (4, 'Creating ResultSet for source %s' % source)
-      controlSection.resultset = self.sources.getDataSource(source)\
-             .getDataObject().createResultSet(readOnly=1)
+      controlSection.resultset = \
+          self.sources.getDataSource(source).createResultSet(readOnly=1)
       if controlSection.resultset.nextRecord():
         controlSection.__nextRecord = controlSection.resultset.current
       else:
@@ -362,6 +361,13 @@ class GRDataMapper(GRDataMapperSection):
       nextSection = None
 
       # Apply the recordset to each section we control,
+      for s in self.sourceMap[source]:
+
+        # Save the new field values in the data handler
+        for field in s.fields.keys():
+          s.fields[field] = recordset.getField(field)
+
+
       # determining the first section to change.
       for s in self.sourceMap[source]:
 
@@ -374,19 +380,23 @@ class GRDataMapper(GRDataMapperSection):
           GDebug.printMesg(10, "After next record, first changed section is %s" % s.name)
           firstSection = s.name
 
-
-        # Save the new field values in the data handler
-        for field in s.fields.keys():
-          s.fields[field] = recordset.getField(field)
+        #   and run formula triggers
+        for formula in s.formulas.keys():
+          if s.formulaObjects[formula] != None:
+            s.formulas[formula] = s.formulaObjects[formula].processTrigger('On-Process')
 
         # ... and save any new summary data
         if s._clearOnNextSet:
           s.clearSummaries()
 
-        for field in s.summaries.keys():
+        for key in s.summaries.keys():
+          field, formula = key
           for function in _summFunctions:
-            if s.summaries[field].has_key(function):
-              s._summMap[function](field, recordset.getField(field))
+            if s.summaries[key].has_key(function):
+              if field != 'none':
+                s._summMap[function](key, recordset.getField(field))
+              elif formula != 'none' and s.formulas.has_key(formula):
+                s._summMap[function](key, s.formulas[formula])
 
         # What will the next section be?
         if (nextSection is None and \
