@@ -16,7 +16,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# Copyright 2000-2004 Free Software Foundation
+# Copyright 2000-2005 Free Software Foundation
 #
 # FILE:
 # GRLayout.py
@@ -44,11 +44,15 @@ class GRSection (ContainerElement):
 
   def __init__(self, parent):
     ContainerElement.__init__(self, parent, 'GRSection')
+
     self._childSections = []
+
     self._validTriggers = {'PRE-SECTION':'Pre-Section',
                            'POST-SECTION':'Post-Section',
                            'ON-PROCESS':'On-Process'}
 
+    self._triggerGlobal = True
+
   def _buildObject(self):
     if not hasattr(self,'name') or self.name == None:
       self._name = id(self)
@@ -56,7 +60,7 @@ class GRSection (ContainerElement):
       self._name = string.lower(self.name)
 
     # Keep track of "child" section names (for the firstRow stuff)
-    psec = self._parent.findParentOfType('GRSection')
+    psec = self.getParent ().findParentOfType('GRSection')
     if psec is not None:
       psec._childSections = self._childSections[:]
       psec._childSections.insert(0, self._name)
@@ -74,6 +78,11 @@ class GRSection (ContainerElement):
        "Controlling section %s's processAsController() called" % self._name)
 
     if self._source == None:
+      for s in mapper.sourceMap[None]:
+        #   and run formula triggers
+        for formula in s.formulas.keys():
+          s.formulas[formula] = s.formulaObjects[formula].processTrigger('On-Process')
+
       # This is a dataless section...
       # simply process it's children
 
@@ -129,8 +138,8 @@ class GRSection (ContainerElement):
   def getAncestorWithSource(self, source):
     if self._source == source:
       return self
-    elif isinstance(self._parent, GRSection):
-      return self._parent.getAncestorWithSource(source)
+    elif isinstance(self.getParent (), GRSection):
+      return self.getParent ().getAncestorWithSource(source)
     else:
       return None
 
