@@ -16,7 +16,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# Copyright 2000-2004 Free Software Foundation
+# Copyright 2000-2005 Free Software Foundation
 #
 # FILE:
 # GRRun.py
@@ -37,6 +37,7 @@ from gnue.reports.base import GRFilters, GRExceptions
 from GRRunUI import GRRunUI
 from gnue.reports.base.GRReportInfo import GRReportInfo
 from gnue.reports.base.GRConfig import ConfigOptions
+from gnue.common.datasources.GLoginHandler import SilentLoginHandler
 import string, sys
 import tempfile
 
@@ -69,7 +70,7 @@ class GRRun(GClientApp):
   #
   def __init__(self):
     self.addCommandOption ('destination', 'd', 'destination',
-        argument = 'dest', default = '-',
+        argument = 'dest',
         help = _("Where should the report be output to?  The value of this "
             "depends on the destination type (e.g., if sending to printer, "
             "then -d specifies the printer name; if sending via email, then "
@@ -80,7 +81,7 @@ class GRRun(GClientApp):
             "Reports is formally released!"))
 
     self.addCommandOption ('destination_type', 'D', 'destination-type',
-        argument = 'type', default = 'file',
+        argument = 'type',
         help = _("This specifies how the report should be output. The currently "
             "supported values for <type> are file [default], printer, email, "
             "and fax. Note that printer, email, and fax are sent via the "
@@ -94,7 +95,7 @@ class GRRun(GClientApp):
             "Example: \'--destination-options \"-o nobanner\" \'"))
 
     self.addCommandOption ('filter', 'f', 'filter',
-        argument = 'filt', default = 'raw',
+        argument = 'filt',
         help = _("Select the filter to be used to process report output.  <filt> "
             "is the name of the filtering process as defined on the Report "
             "Server machine. If not specified, the \"raw\" filter is used "
@@ -221,8 +222,7 @@ class GRRun(GClientApp):
       sortoption      = runui.getSortOption ()
 
     else:
-      lh = NoLoginHandler()
-      self.getConnectionManager().setLoginHandler(lh)
+      self.getConnectionManager().setLoginHandler(SilentLoginHandler ())
 
     #
     # Now, run an engine instance
@@ -336,28 +336,6 @@ class GRRun(GClientApp):
   def getReportInformation(self, location):
     return GRReportInfo(location)
 
-
-
-#
-# Login handler for --batch mode
-#
-from gnue.common.datasources import GLoginHandler
-class NoLoginHandler(GLoginHandler.LoginHandler):
-
-  defaults = {'_username': None, '_password': None}
-
-  def getLogin(self, loginData, error):
-    val = {}
-    for prompt in loginData[2]:
-       if self.defaults.has_key(prompt[0])  and self.defaults[prompt[0]]:
-         val[prompt[0]] = self.defaults[prompt[0]]
-       else:
-         val[prompt[0]] = None
-    return val
-
-  def destroyLoginDialog(self):
-    pass
-
 if __name__ == '__main__':
   GRRun().run()
 
