@@ -1,6 +1,6 @@
 # GNU Enterprise Reports - Run/create a user interface for starting a report
 #
-# Copyright 2001-2004 Free Software Foundation
+# Copyright 2001-2005 Free Software Foundation
 #
 # This file is part of GNU Enterprise
 #
@@ -19,7 +19,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: GRRunUI.py 6662 2004-11-09 14:00:28Z johannes $
+# $Id: GRRunUI.py 7670 2005-07-01 08:22:15Z reinhard $
 
 import string
 import StringIO
@@ -27,6 +27,7 @@ import mx
 
 from gnue.common.apps import errors
 from gnue.common.utils.FileUtils import dyn_import
+from gnue.common.datasources.GLoginHandler import BasicLoginHandler
 
 
 # =============================================================================
@@ -68,7 +69,11 @@ class GRRunUI:
 
     if ui == 'text':
       self.uimodule     = None
-      self.loginhandler = LoginHandler ()
+
+      from GRRun import quietprint, _quietprintSuppress
+      silent = quietprint == _quietprintSuppress
+
+      self.loginhandler = BasicLoginHandler (True, silent)
     else:
       self.loginhandler = self.uimodule.UILoginHandler ()
 
@@ -101,7 +106,6 @@ class GRRunUI:
       instance   = self.gfinstance.GFInstance (self, self.connections,
                                       self.uimodule, True, self.userParameters)
       instance.addFormFromFilehandle (formBuffer)
-      instance.addDialogs ()
       instance.activate ()
 
       # Now iterate through the parameters dictionary and fetch our 'private'
@@ -608,51 +612,3 @@ class GRRunUI:
       result.append ("%s</%s>" % (indent, tag))
 
     return result
-
-
-#
-# This is a (temporary?) solution to getting a login
-#
-from gnue.common.datasources import GLoginHandler
-
-try:
-  import getpass
-except:
-  getpass = None
-
-class LoginHandler(GLoginHandler.LoginHandler):
-
-  defaults = {'_username': None, '_password': None}
-
-  def getLogin(self, loginData, error):
-    try:
-      from GRRun import quietprint, quietprint_nl
-      quietprint ( "*"*60 )
-      if len(loginData[1]):
-        quietprint ( 'Attempting to log into "%s" (%s):' % (loginData[1], loginData[0]) )
-      else:
-        quietprint ( 'Attempting to log into %s:' % (loginData[0]) )
-      quietprint ("")
-      val = {}
-      for prompt in loginData[2]:
-         if self.defaults.has_key(prompt[0])  and self.defaults[prompt[0]]:
-           quietprint_nl ( "  %s: " % prompt[1] )
-           if prompt[2]:
-             quietprint ( "***" )
-           else:
-             quietprint ( self.defaults[prompt[0]] )
-           val[prompt[0]] = self.defaults[prompt[0]]
-         else:
-           if prompt[2] and getpass:
-             val[prompt[0]] = getpass.getpass("  %s: " % prompt[1])
-           else:
-             val[prompt[0]] = raw_input("  %s: " % prompt[1])
-      quietprint ("")
-      quietprint ("*"*60)
-      return val
-    except KeyboardInterrupt:
-      raise GLoginHandler.UserCanceledLogin
-
-
-  def destroyLoginDialog(self):
-    pass
